@@ -4,12 +4,13 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/pkg/errors"
 
+	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
+
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
 
-	"github.com/batchcorp/plumber/printer"
+	"github.com/streamdal/plumber/printer"
 )
 
 // DisplayMessage will parse a Read record and print (pretty) output to STDOUT
